"""Implementation of XBAspecies class.

Peter Schubert, HHU Duesseldorf, May 2022
"""

import sbmlxdf


class XbaSpecies:

    def __init__(self, s_species):
        self.id = s_species.name
        self.name = s_species.get('name', '')
        self.sboterm = s_species['sboterm']
        self.compartment = s_species['compartment']
        self.initial_conc = s_species['initialConcentration']
        self.constant = s_species['constant']
        self.units = s_species['substanceUnits']
        attrs = sbmlxdf.misc.extract_xml_attrs(s_species['xmlAnnotation'], token='molecule')
        self.weight = float(attrs['weight_Da'])
        self.m_reactions = {}
        self.ps_reactions = {}
        self.ps_rid = None
        self.p_degrad_rid = None
        self.p_convert_rid = None

    def add_m_reaction(self, rid, stoic):
        self.m_reactions[rid] = stoic

    def add_ps_reaction(self, rid, stoic):
        self.ps_reactions[rid] = stoic

    def set_ps_rid(self, rid):
        self.ps_rid = rid

    def set_p_degrad_rid(self, rid):
        self.p_degrad_rid = rid

    def set_p_conversion_rid(self, rid):
        self.p_convert_rid = rid
